@@ -12,7 +12,7 @@ use XTM::subjectIndicatorRef;
 
 @ISA = qw(Exporter AutoLoader XTM::generic);
 @EXPORT = qw( );
-$VERSION = '0.01';
+$VERSION = '0.02';
 
 =pod
 
@@ -28,6 +28,21 @@ XTM::parameters - trivial class definition
 
 Generic container for accessor functions.
 
+=cut
+
+sub xml {
+  my $self   = shift;
+  my $writer = shift;
+
+  $writer->startTag ('parameters');
+  foreach my $r (@{$self->references}) {
+    $r->xml ($writer);
+  }
+  $writer->endTag ('parameters');
+};
+
+=pod
+
 =head1 SEE ALSO
 
 L<XTM>
